#include "msp430.h"
#include "stdio.h"
#include "lib/radio_drv/radio_drv.h"
#include "lib/radio_drv/cc1x_utils.h"
#include "lib/radio_drv/hal_spi_rf.h"
#include "lib/uart_drv/uart_drv.h"
#include "LaunchPad_trx_demo.h"

/******************************************************************************
 * LOCAL FUNCTIONS
 */
extern void msp_setup(void);
unsigned long volatile time_counter;

/******************************************************************************
 * GLOBALS
 */
char u_str[UART_BUFF_SIZE];
unsigned char txBuffer[TX_BUFF_SIZE];
char user_button_pushed;
unsigned char wakeup_on_wdt;
trx_cfg_struct trx_cfg;


/******************************************************************************
 * @fn         main
 *
 * @brief      Main GUI application level control loop is implemented in the
 *             main loop. It is a state machine that cycles thru various states
 *             during the interactive use by the operator. The presents a text
 *             based GUI, the user is then promted to type in a command with
 *             a given set of parameters. The state machine then calls a simpler
 *             parser that tries to figure out what the user wants to do.
 *
 * input parameters
 *
 * @param       void
 *
 * output parameters
 *
 * @return      void
 *
 */
enum state_names {IDLE_RESET, WAIT, OPERATE};
void main (void)
{

	char idle_counter = 0;
	unsigned char u_str_length;
  enum state_names state = WAIT;

	/*  Stop WDT */
	WDTCTL = WDTPW + WDTHOLD;

	/* Setup MSP specific functions, IO's, timers and WDT */
    //Comes from lib/hal_mcu/hal_mcu.c
	msp_setup();

	/* Initialize the UART port */
	hal_uart_init();

	/* enable uart echo function */
	//uart_drv_toggle_echo();

	/* initialize the radio subsystem */
	//trx_cfg.bit_rate = radio_init(1);
	//trx_cfg.bit_rate = trx_cfg.bit_rate * 100;

	// Perform initial setup of the CC radio
	//trx_cfg.b_length = TX_BUFF_SIZE;
	//rf_default_setup(&trx_cfg);

	/* Configure LED ports */
  // Defined in hal_spi_rf_exp430fr5994
	LED1_PxDIR |= LED1_PIN;
	LED2_PxDIR |= LED2_PIN;
	LED3_PxDIR |= LED3_PIN;
	LED4_PxDIR |= LED4_PIN;

	/* default all LEDs to off */
	HAL_LED1_OFF();
	HAL_LED2_OFF();
	HAL_LED3_OFF();
	HAL_LED4_OFF();

	/* Generally we use the WDT time wake the statemachine */
	wakeup_on_wdt = 1;

	/* indicator that button has been pressed */
	user_button_pushed = 0;

	/* Infinite loop with a 1 second timer */
	while(1)
	{

		/* Put MCU in low power mode, wait for UART and blink LED */
		//Skip Low power mode to debug
		HAL_LED2_OFF();
		//_BIS_SR(LPM0_bits + GIE);
		HAL_LED2_ON();
		idle_counter++;


		/*
		 *    Main loop of state machine
		 */
		switch(state)
		{
		/* print the tick state to the UART buffer */
		case WAIT:
            if(time_counter>5){
                state = IDLE_RESET;
                uartSendString("Tic:\n\r");
                time_counter = 0;
            }
			state = OPERATE;
			HAL_LED1_OFF();
            break;
        case OPERATE:
            if(time_counter>5){
                state = WAIT;
                uartSendString("Tic:\n\r");
                time_counter = 0;
            }
			HAL_LED1_ON();
            break;
		default:
			state = WAIT;
			break;
		}
	}
}


/******************************************************************************
 * @fn         uartSendString
 *
 * @brief      Implements a simple uart string sender by automatically finding
 *             the end of line delimeter and using it to call the uart sub
 *             functions
 *
 * input parameters
 *
 * @param            unsigned char *str
 *
 * output parameters
 *
 * @return      void
 *
 */
void uartSendString(char *str)
{
	unsigned char ii;

	for(ii=0;ii<UART_BUFF_SIZE;ii++)
	{
		if(str[ii] == 13)
		{
			uart_put_str(str, ii+1);
			ii = UART_BUFF_SIZE;
		}
	}
	return;
}

/******************************************************************************
 * @fn         wdt_isr
 *
 * @brief      Interrupt service routine for watch dog timer.
 *
 * input parameters
 *
 * @param       void
 *
 * output parameters
 *
 * @return      void
 *
 */
HAL_ISR_FUNC_DECLARATION(wdt_isr,WDT)
{
	/* global "0.5 second" counter used for printing time stamped packet sniffer data */
	time_counter++;

	/* check to see if wake on wdt is enabled */
	if(wakeup_on_wdt == 1)
	{

		/* exit from low power mode on ISR exit */
		//_BIC_SR_IRQ(LPM3_bits);
	}
}
