#include "msp430fr5994.h"
#include "stdio.h"
#include "lib/radio_drv/hal_types.h"
#include "lib/hal_mcu/hal_mcu_fr5.h"

/******************************************************************************
 * LOCAL FUNCTIONS
 */
extern void msp_setup(void);
unsigned long volatile time_counter;



/******************************************************************************
 * @fn         main
 *
 * @brief      Main GUI application level control loop is implemented in the
 *             main loop. It is a state machine that cycles thru various states
 *             during the interactive use by the operator. The presents a text
 *             based GUI, the user is then promted to type in a command with
 *             a given set of parameters. The state machine then calls a simpler
 *             parser that tries to figure out what the user wants to do.
 *
 * input parameters
 *
 * @param       void
 *
 * output parameters
 *
 * @return      void
 *
 */

enum state_names {IDLE_RESET, WAIT, OPERATE};
void main (void)
{

	int idle_counter = 0;

	/*  Stop WDT */
	WDTCTL = WDTPW + WDTHOLD;

	/* Setup MSP specific functions, IO's, timers and WDT */
    //Comes from lib/hal_mcu/hal_mcu.c
	msp_setup();

	// Enable the interupts on port 2 to catch the user button (TRXEB)



	P1DIR |= BIT0 | BIT1;
	__enable_interrupt();
	/* Infinite loop with a 1 second timer */
	while(1)
	{
		P1OUT ^= BIT0;
		_delay_us(4166);
		_delay_us(8332);
	}
}

/******************************************************************************
 * @fn         wdt_isr
 *
 * @brief      Interrupt service routine for watch dog timer.
 *
 * input parameters
 *
 * @param       void
 *
 * output parameters
 *
 * @return      void
 *
 */
HAL_ISR_FUNC_DECLARATION(wdt_isr,WDT)
{
	/* global "0.5 second" counter used for printing time stamped packet sniffer data */
	P1OUT ^= BIT1;

}
